package cn.bunny.user.service.impl;

import cn.bunny.common.exception.BunnyException;
import cn.bunny.common.spzx.model.dto.h5.UserRegisterDto;
import cn.bunny.common.spzx.model.entity.user.UserInfo;
import cn.bunny.common.spzx.model.vo.common.ResultCodeEnum;
import cn.bunny.user.mapper.UserinfoMapper;
import cn.bunny.user.service.UserinfoService;
import jakarta.annotation.Resource;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.util.DigestUtils;

@Service
public class UserinfoServiceImpl implements UserinfoService {
    @Resource
    private RedisTemplate redisTemplate;
    @Resource
    private UserinfoMapper userinfoMapper;

    // 会员注册
    @Override
    public void register(UserRegisterDto userRegisterDto) {
        // 1. userLoginDto获取数据
        String username = userRegisterDto.getUsername();
        String password = userRegisterDto.getPassword();
        String nickName = userRegisterDto.getNickName();
        String code = userRegisterDto.getCode();
        // 2. 从Redis获取发送验证码
        String redisCode = (String) redisTemplate.opsForValue().get(username);
        // 3. 获取输入验证码，进行对比
        if (!redisCode.equals(code)) {
            throw new BunnyException(ResultCodeEnum.VALIDATECODE_ERROR);
        }
        // 4. 校验用户名不重复
        UserInfo userInfo = userinfoMapper.getByUsername(username);
        if (userInfo != null) {
            throw new BunnyException(ResultCodeEnum.USER_NAME_IS_EXISTS);
        }
        // 5. 封装添加数据，调用方法调用添加数据
        userInfo = new UserInfo();
        userInfo.setUsername(username);
        userInfo.setNickName(nickName);
        userInfo.setPassword(DigestUtils.md5DigestAsHex(password.getBytes()));
        userInfo.setPhone(username);
        userInfo.setStatus(1);
        userInfo.setSex(0);
        userInfo.setAvatar("http://thirdwx.qlogo.cn/mmopen/vi_32/DYAIOgq83eoj0hHXhgJNOTSOFsS4uZs8x1ConecaVOB8eIl115xmJZcT4oCicvia7wMEufibKtTLqiaJeanU2Lpg3w/132");
        userinfoMapper.save(userInfo);
        // 6. 从Redis中删除发送验证码
        redisTemplate.delete(username);
    }
}
